### A Pluto.jl notebook ###
# v0.20.4

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    #! format: off
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
    #! format: on
end

# ╔═╡ a145e2fe-a903-11eb-160f-df7ea83fa3e6
begin
	using HypertextLiteral ,  PlutoUI, LinearAlgebra, NLsolve, PlutoPlotly
end

# ╔═╡ ee5192d8-a3fb-4a81-b9a0-746a19a2d7e0
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
"""

# ╔═╡ 943edb36-acc8-4b2a-94ab-c544f9eb279b
md"""
# Week 8 - The AD/AS Model & Macroeconomic Equilibrium

# Exercises

**Macroeconomics, ISCTE-IUL**
"""

# ╔═╡ 1245aef9-18ce-42f5-af82-c2e6cce70798
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas**

**March 2025**
"""

# ╔═╡ a6c1f828-e06d-43f1-a26b-15cd3a26f7d4
md"""
---
"""

# ╔═╡ 4618a663-f77e-4ccc-9b00-e84dbd5beb34
md"""
## Packages
"""

# ╔═╡ e593a1eb-4d26-4fdf-b1ac-c7da27d319ef
md"""
---
"""

# ╔═╡ 0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
md"""
## Exercise 1. Tax incentives and the AD curve
"""

# ╔═╡ 5999a598-0408-44f1-bd33-c4d0fa5a6006
md"""

*From the textbook.*


Suppose that Congress passes legislation that establishes a tax credit for small businesses
and tax incentives for all businesses that invest in new plant and equipment. 

👉 a) What is the anticipated effect of these proposals on aggregate demand, if any?

"""

# ╔═╡ f52137ff-9ac8-4bf1-930e-423b0347622a
md"""
!!! hint

	A “tax credit” refers to an amount of money that taxpayers can subtract directly from the taxes they were supposed to pay.

"""

# ╔═╡ 93ae1892-7c2d-4dec-925d-1803d77bd36a
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 8034f9ea-d35d-4fa0-b246-503ee7c4fd60
md"""
👉 b) Show your answer graphically.
"""

# ╔═╡ 4b63f599-4622-472e-a7fb-685c522681dc
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 1badc5a8-42dd-409a-a0aa-b33fcc3cfbf4
Resource("https://vivaldomendes.org/images/depot/demand_shock.png",:width=>600)

# ╔═╡ c5c3b106-f7ec-44c4-abcd-03497f7873c7
md"""
---
"""

# ╔═╡ 7342ebd8-e148-43a3-a9cb-24ea0ed917ac
md"""
## Exercise 2. Dollar appreciation and the AD curve
"""

# ╔═╡ cf299465-4844-4580-83da-769c966e2569
md"""

*From the textbook.*

Evaluate the accuracy of the following statement: “The recent appreciation of the U.S. dollar has had a negative effect on the U.S. aggregate demand curve.”
"""

# ╔═╡ 549d9eda-f104-4b6c-9524-5c08ea11e7b3
md"""
!!! answer
	Here 
"""

# ╔═╡ 906529c8-51e1-43c6-9ead-f162d9ffbb83
md"""
---
"""

# ╔═╡ 0836abe7-5ea6-4189-b783-a2215b6acd72
md"""
## Exercise 3. Public spending and the AD curve
"""

# ╔═╡ 4ce820d4-9eb2-4acd-92c7-820cf46d08ae
md"""

*From the textbook.*

Suppose that the White House decides to sharply reduce military spending without increasing government spending in other areas.

👉 a) Comment on the effect of this measure on aggregate demand.

👉 b) Show your answer graphically.
"""

# ╔═╡ 5726cb84-b09b-4efc-94da-19777ecabae4
md"""
!!! answers

	(a) Here

	(b) Here

"""

# ╔═╡ 959f9b39-b525-4394-ae21-9453a45a28b1
Resource("https://vivaldomendes.org/images/depot/demand_shock2.png",:width=>600)

# ╔═╡ 14972c0b-a403-4c98-b15e-ea033758c104
md"""
---
"""

# ╔═╡ 5d0cee9b-73c6-4b7e-bb0f-6773be82f845
md"""
## Exercise 4. Oil prices and the AS curve
"""

# ╔═╡ c7da461d-1fc4-463e-bd46-900df67d1e03
md"""

*From the textbook.*


Oil prices declined in the summer of 2008, following months of increases since the winter of 2007. Considering only this fall in oil prices, explain the effect on short-run aggregate supply and long-run aggregate supply, if any.
"""

# ╔═╡ dc128d55-9ba7-44a1-aec8-f448f131746d
md"""
!!! answer

	Here

"""

# ╔═╡ c4e8ddf3-2501-42fc-a24d-84dd81026f33
md"""
---
"""

# ╔═╡ add07024-b7eb-445d-b4f4-6a6757c2ecd3
md"""
## Exercise 5. A demand shock (numerical exercise)
"""

# ╔═╡ 498da362-6b02-4335-9525-ad82aa6fb5a2
md"""
!!! note "Note 1"
    This week, we will leave the MP curve out of our exercises. Next week, we will deal with the AD/AS/MP model; therefore, the MP curve will be present in the exercises. So, during the current week, we will not be concerned about the real and the nominal interest rates; we will only be worried about GDP and inflation.
"""

# ╔═╡ 8e2203e6-6677-47b9-8032-e9c63c0f41bb
md"""
Consider two fundamental curves of our macroeconomic model: the AD and AS curves:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  

\end{align*}$$

and the following information concerning exogenous variables and parameters:

$$\begin{aligned}
&\overline{A}=7.6 \ , \ m=2.0 \ , \ \phi=0.2 \ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma= 4.5 \ , \ Y^{P}=14.0 \ , \ \rho=0.
\end{aligned}$$

Note that $\left\{\pi^{e}, \overline{r}, r, i , \rho \right\}$ are rates and measured in percentage points
(e.g., $2.0$ means $2.0\%$), while $\{Y, Y^P , \overline{A}\}$ are measured in trillion dollars. In the solutions below, to avoid doubt, we put the symbol % only at the final step of the solutions.
"""

# ╔═╡ a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
begin
	
	Ā5 = 7.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.2 ;	r̄5 = 2.0 	# Demand-side parameters and exogenous variables	
	
	γ5 = 4.5 ; Yᴾ5 = 14.0 ; πᵉ5 = 2.0 ; ρ5 = 0.0 			# Supply-side parameters and exogenous variables				
end;

# ╔═╡ a0d0e633-d674-4163-864f-db877bd9e986
md"""
__________________________________________________________________________________________________________________
"""

# ╔═╡ 31625342-4ea6-4831-b131-dbd0195b6361
md"""

👉 a) Calculate the short-run equilibrium values of GDP and the inflation rate. Represent graphically, involving the AD and AS curves.

"""

# ╔═╡ 7c8767ed-5600-49e5-869b-b1d3cd773f55
md"""
!!! note "Note 2" 
	We will use the `NLsolve` package to solve the entire model. The routine is the same as in Weeks 1 and 2. All we need to do is copy one of those routines and adapt it to the current  exercise.
"""

# ╔═╡ af38d9e1-a2c2-4fd6-a06f-bf68813065e5


# ╔═╡ 732496c1-43d8-4457-bada-8a3255cbf43d
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ d1f298ae-0249-420f-a0d4-f7548c5dd1c6
md"""
👉 b) Is the economy in a recession or in an economic boom? Justify.
"""

# ╔═╡ ffb1afa6-5348-4dc3-9c63-3b01ecc63743
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 8a3260f2-88a9-4c93-a936-e2688f4c0dea
md"""
👉 c) If there is no demand or supply shock, what will happen to the economy over time?

"""

# ╔═╡ 2c004ab0-8cc6-4d9f-8b50-35eadf58e92b
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ ee80a41f-5d29-46b4-8f64-23b6f5a37895
md"""
👉 d) Suppose the government, to stimulate economic activity, increases its spending on goods and services (G&S) by 0.2 trillion dollars. Describe what will happen to the economy over time. What will be the new value of the long-run equilibrium inflation rate? Use the sliders `ΔĀ5` and `self_correction` below to graphically represent this policy measure's impact.
"""

# ╔═╡ 4a876a3f-e3b7-4fc3-a906-7fa91cb0728f
md"""
!!! answer "Answer (d)"

	Here

"""

# ╔═╡ 7982723e-690b-494a-9560-8853ef8bc535
md"""
---
"""

# ╔═╡ dcd13560-0f73-4aaa-b59a-b7961d8cdc63
md"""
## Exercise 6. A supply shock (numerical exercise)
"""

# ╔═╡ 7f67d656-bb55-4097-ba49-10140f9b3502
md"""
Consider the same values for the parameters and the exogenous variables of Exercise 5. However, due to a sharp decline in oil prices, a positive supply shock of $\rho = -1.9$ exists. 

👉 a) Calculate the short-run equilibrium values for the inflation rate and the GDP level resulting from such a shock. Using the slider `ρ6` below, represent this shock graphically, involving the AD and AS curves.

"""

# ╔═╡ 82a2c755-960e-4eb7-a55a-e333eb85fa5f
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 22fd1017-4015-407d-bd79-188a763e87a4
md"""
`ρ6 = `$(@bind ρ6 Slider(-3.0:0.1:3.0, default=0.0, show_value=true))
"""

# ╔═╡ 18254af8-8305-4953-8ff8-3a1685605c06
md"""
👉 b) Is the economy in a recession or an economic boom? Justify.

"""

# ╔═╡ 28052403-f02e-41dc-ba74-e42d88f3d494
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ b95fd035-9752-428b-b908-206bf0bf26e6
md"""
👉 c) If there are no further supply or demand shocks, what will happen to the economy over time?
"""

# ╔═╡ db702f28-e3e7-4d14-9209-1cbe2917247b
md"""
`self6 = `$(@bind self6 Slider(-4.0:0.1:4.0, default=0.0, show_value=true))
"""

# ╔═╡ 5859e1fa-f4ef-42b7-a3fd-5085cd64161c
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 6f7751bd-71c8-4cfd-982e-69690f401034
md"""
---
"""

# ╔═╡ ec34cbc5-fda5-4792-adc8-3bb0d02a7f22
md"""
## Exercise 7. A permanent supply shock (numerical exercise)
"""

# ╔═╡ 83c030a3-28bc-419f-968b-62ce9ab0a1e4
md"""
Consider Exercise 6 with one change: suppose the supply shock is **permanent** instead of temporary; oil prices go down, and then they will stay there for an extended period. This positive shock will cause the Potential GDP to increase by 0.2 trillion dollars. 

👉 a) How would we change our answers to the raised three questions?

"""

# ╔═╡ b731c7e2-1db6-4cee-bb97-c9267d89d099
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 7e726480-d4c0-4389-abe8-d83f4dff3914
md"""
👉 b) Calculate the short-run and long-run equilibrium values for the inflation rate and the GDP level resulting from such a shock. Using the slider `self7`, represent the new equilibrium graphically.
"""

# ╔═╡ 6b3b698d-4cce-459d-af5a-bd756ffe0d19
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 270c5421-dc6d-4278-861e-3d70a003858a
md"""
👉 c) Is the economy in a recession or an economic boom? Justify.
"""

# ╔═╡ 39077452-b48d-475e-ae62-1a27f164128b
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ bfd1415f-da2e-49ea-aee2-08eaa2537042
md"""
👉 d) If there are no further supply or demand shocks, what will happen to the economy over time?
"""

# ╔═╡ 6f7be7b0-6bab-4521-a344-86a559f2a107
md"""
!!! answer "Answer (d)"

	Here

"""

# ╔═╡ e1db11e3-f0fb-41e1-b9ad-52a2792c2fe3
md"""
---
"""

# ╔═╡ 57864011-a2c9-410a-b6c9-9d27ee2cb74a
md"""
## Exercise 8. Negative supply shocks in the 1970s
"""

# ╔═╡ e1bf534b-55a6-490c-8038-ddedc6ec6475
md"""
*On page 310 in the textbook:*

>"In 1973, the U.S. economy was hit by a series of negative supply shocks:
>1. As a result of the oil embargo stemming from the Arab–Israeli war of 1973, the Organization of Petroleum Exporting Countries (OPEC) engineered a quadrupling of oil prices by restricting oil production.
>2. A series of crop failures throughout the world led to a sharp increase in food prices.
>3. The termination of U.S. wage and price controls in 1973 and 1974 led to a push by workers to obtain wage increases that had been prevented by the controls.
>The triple thrust of these events shifted the short-run aggregate supply curve sharply upward."

👉 a) What would we expect about the behavior of inflation in the 1970s?

"""

# ╔═╡ 60c7a5e9-9d69-4cd8-8d8a-e02b7910ff05
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 8ed2e8bd-546f-41d0-acb8-ffee83c29b6e
md"""
👉 b) Can we explain what happened to the US economy in the 1970s with the AD/AS model? 
"""

# ╔═╡ 487a5208-4cc6-489e-8613-3fa8d5bc0603
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ 1b4b25ee-89cb-4322-b358-994fe912cc74
md"""
---
"""

# ╔═╡ e10c1813-957e-4da8-90dc-8ced5d2084d1
md"""
## Appendix 1 : Solving Exercise 5 with linear algebra
"""

# ╔═╡ af27ace7-dc5b-444b-b4c7-7848f5922584
md"""
To see how this method works, let us recall that our model is the following:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  
\end{align*}$$


Let us re-write the model with the endogenous variables on the left-hand side of the system, while the exogenous variables will be placed on its right-hand side. As follows:

$$\begin{align*}
\text{AD}: \quad Y + (m \phi \lambda) \pi &=m \cdot \overline{A} - (m \phi) \overline{r}\\[3mm]           
\text{AS}: \quad  -\gamma \cdot Y + \pi &=\pi^{e}+\gamma \cdot Y^{P} +\rho \\[3mm]  
\end{align*}$$

Now, we can write the model in matrix form as follows:

$$\underbrace {\left[\begin{array}{cc}
1 & m  ϕ  λ \\
-\gamma & 1
\end{array}\right]}_{A} \cdot \underbrace {\left[\begin{array}{l}
Y \\
\pi
\end{array}\right]}_{Q}
= 
\underbrace {\left[\begin{array}{ccccc}
m & - m \phi & 0 & 0 & 0 \\
0 & 0 & 1 & -\gamma & 1
\end{array}\right]}_{B} \cdot
\underbrace { \left[\begin{array}{cc}
\overline{A} \\
\overline{r} \\
\pi^e \\
Y^P \\
\rho
\end{array}\right]}_{H}$$

So, we have our model simplified as follows:

$$A \times Q = B \times H$$

which can be written as:

$$Q = (A^{-1}B) H$$

where $Q$ is the set of endogenous variables, $H$ is the set of exogenous variables, and $A^{-1}B$ gives the structure of the model, that is, how inputs $(H)$ are transformed into outputs $(Q)$. Notice that $A^{-1}$ is the notation usually used in linear algebra to express the inverse of $A$. 

Now, solving the model is extremely easy. Just tell the notebook what are the elements of matrices $A$,$B$ and $H$, and apply the command:

		Q = inv(A)*B*H

"""

# ╔═╡ 235353dd-e5f0-4830-b1bc-ae3de9787168
md"""
The equilibrium can be calculated as follows:
"""

# ╔═╡ 84e2f9cd-f9b0-40ac-b65c-6be18bcb80d7
begin
	A = [1.0  m5*ϕ5*λ5 ; -γ5   1] 						# This is  matrix A
	
	B = [m5  -m5*ϕ5  0   0   0  ;  0   0  1  -γ5  1] 	# This is matrix B

	H = [Ā5 ; r̄5 ; πᵉ5 ; Yᴾ5 ; ρ5] 						# This is matrix H
	
	Q = inv(A) * B * H									# Q = (A \ B) * H is better if the matrices are very large
end


# ╔═╡ 07f14b05-4049-4a4f-a3a7-0b2e1c48b8a1
md"""
!!! answer

	As we can easily see, 

	$$\pi = 2\% \ \ , \ \ Y=14.0 \ \text{trillion dollars}$$ 

	The same result as the one obtained uisng the `NLsolve` method.
"""

# ╔═╡ 26fe310e-9ed8-4d09-bb82-a5bd39193dde
md"""
# Reality Check (this is optional reading)
"""

# ╔═╡ 23a5d2a0-d780-4e7b-be00-1f8851fd5d86
md"""
!!! note

	These applications that are presented below are not compulsory reading.
"""

# ╔═╡ b7d79351-21e6-491b-89f0-7ab76b437eef
md"""

Sometimes, arguing that "economic models are useless" in some corners of public life is pretty colorful. Even in pretty respectable corners, we may find similar comments, like on the October 11, 2017, edition of the ["Financial Times"](https://www.ft.com/content/333b3406-acd5-11e7-beba-5521c713abf4)

>*"Central bankers usurped the titans of Wall Street as the masters of the universe almost a decade ago. They rescued the global economy from the financial crisis. [However, now, ten years on], as they gather in Washington for the annual meetings of the International Monetary Fund, there is a crisis of confidence in central banking. **Their economic models are failing**, and there are doubts about whether they understand the effects of interest rates and other monetary policies on the economy.*

>*In short, the new masters of the universe might not understand what makes a modern economy tick, and their well-intentioned actions could prove harmful."*

Our textbook is quite excellent regarding the link between theory and practice. In Chapter 12, there are **seven** applications of theory that are helpful for this reality check. We provide three of them here because it is crucial to make this check and see if the nihilistic ideas about economic models make any sense.

Sometimes, policymakers may not make the right decisions, not because their models are wrong but because they do not fully trust them; they put more trust in their "intuition," as happened in 2006/2007 with the housing bubble. Everything pointed at a housing bubble that was on the verge of bursting, but the Fed did not want to believe it.

It is also possible that the models provide a valuable description of economic reality, but political constraints speak louder than the models themselves. Once again, the models may help manage an economy, but they are put aside for reasons that have nothing to do with them.

"""

# ╔═╡ b974cf81-fa40-47fb-a362-ac7ec6e20a94
md"""
## Application 1. Negative demand shocks, 2001–2004
"""

# ╔═╡ b108dd56-8868-460d-a042-d38a4bcb10d6
md"""
*On page 310 in the textbook:*

>"In 2000, the U.S. economy was expanding when it was hit by a series of negative shocks to aggregate demand. 
>1. The “tech bubble” burst in March 2000 and the stock market fell sharply. 
>2. The September 11, 2001, terrorist attacks weakened both consumer and business confidence. 
>3. The Enron bankruptcy in late 2001 and other corporate accounting scandals in 2002 revealed that corporate financial data were not to be trusted, and so financial frictions increased. Interest rates on corporate bonds rose as a result, making it more expensive for corporations to finance their investments."

**Can we explain the recession of 2001 with the AD/AS model?**
"""

# ╔═╡ 7e0ae435-0c4d-45b3-b021-9c17cde55edc
md"""
!!! answer

	Here

"""

# ╔═╡ be4b71e0-d6ee-4e14-bb0b-5c1eefb03757
md"""
---
"""

# ╔═╡ 7f7f259b-fb40-4c45-a78c-24d9be188c55
md"""
## Application 2. Positive supply shocks, 1995–1999
"""

# ╔═╡ e16fd560-114f-4e13-938b-1604ff43c273
md"""
*On page 316 in the textbook:*

>_"In February 1994, the Federal Reserve began to raise interest rates. It believed the economy would be reaching potential output and the natural rate of unemployment in 1995, and it might become overheated thereafter, with output climbing above potential and inflation rising. As we can see in panel (b) of Figure 12.9, however, the economy continued to grow rapidly, with the unemployment rate falling to below 5% in 1997. Yet inflation continued to fall, declining to around 1.6% in 1998."_

**Can the aggregate demand and supply analysis explain what happened?** 

"""

# ╔═╡ 0bba272d-1d00-4ea8-9583-dff318cd8b36
md"""
!!! answer

	Here

"""

# ╔═╡ cbdd006a-2fc3-48c0-9a4b-d7705e88bd41
md"""
---
"""

# ╔═╡ dd6bcb46-31de-40d1-af36-2db046dde140
md"""
## Application 3. The perfect storm: 2007-2009
"""

# ╔═╡ 324f74c7-fe71-4bd6-baf0-51f8c3211006
md"""
*On page 316 in the textbook:*

>_"We described the perfect storm of 2007–2009 in the chapter opener. At the beginning of 2007, higher demand for oil from rapidly growing developing countries like China and India and the slowing of production in places like Mexico, Russia, and Nigeria drove up oil prices sharply from around the $60 per barrel level. By the end of 2007, oil prices had risen to $100 per barrel, and they reached a peak of over $140 per barrel in July 2008. The run up of oil prices, along with increases in other commodity prices, led to a negative supply shock that shifted the short-run aggregate supply curve (shown in panel (a) of Figure 12.10) sharply upward from AS1 to AS2. To make matters worse, a financial crisis hit the economy starting in August 2007, causing a sharp increase in financial frictions, which led to contraction in both household and business spending (more on this in Chapter 15)."_

**Can we explain what happened to the US economy in that period with the AD/AS model?**
"""

# ╔═╡ 68e70c98-2a58-474d-89dd-76f2db735e5a
md"""
!!! answer

	Here

"""

# ╔═╡ 00b94ba0-4536-499e-8e4e-8d78f50be9f9
md"""
---
"""

# ╔═╡ 83888153-57b4-4cc2-adde-3eb65d2dc70d
md"""
## Auxiliary cells (do not delete)
"""

# ╔═╡ 9fa87191-7c90-4738-a45a-acd929c8bd1b
  TableOfContents()

# ╔═╡ b3ead675-fabb-418c-92b7-3d37bce22614
md"### CSS code"

# ╔═╡ 07fb6f85-d9c2-4f3b-9988-eb5ba294fb34
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1560px;
    		padding-left: max(100px, 10%);
    		padding-right: max(380px, 10%); 
            # 383px to accomodate TableOfContents(aside=true)
		}
	}
</style>
"""

# ╔═╡ 19930b0f-e3f0-45e0-b829-9def3f828bbc
begin
      struct TwoColumns{L, R}
    left::L
    right::R
      end
      
      function Base.show(io, mime::MIME"text/html", tc::TwoColumns)
          write(io, """<div style="display: flex;"><div style="flex: 48%;margin-right:2%;">""")
          show(io, mime, tc.left)
          write(io, """</div><div style="flex: 48%;">""")
          show(io, mime, tc.right)
          write(io, """</div></div>""")
      end
end

# ╔═╡ 70d9bdc7-342f-40a0-bf1d-996b8acedd0c
TwoColumns(
md"""

`ΔĀ5 = `$(@bind ΔĀ5 Slider(-1.0:0.05:1.0, default=0.0, show_value=true))

""",
	
md"""

`self_correction = `$(@bind self_correction Slider(-4.0:0.5:4.0, default=0.0, show_value=true))

"""
)

# ╔═╡ 996d86b1-736d-40fe-9426-c4bf64273259
TwoColumns(
md"""

`ΔYᴾ = `$(@bind ΔYᴾ Slider(-1.0:0.1:1.0, default=0.0, show_value=true))

""",
	
md"""

`self7 = `$(@bind self7 Slider(-4.0:0.1:4.0, default=0.0, show_value=true))

"""
)

# ╔═╡ 3d970676-1703-4773-8fd5-8a415fea2b69
md"""
##### Exercise 5. Supporting cells
"""

# ╔═╡ 505df01a-8e06-43c0-8c36-3548f2fa1e97
begin
	
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5 									# The AD curve y-axis' intercept
	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5 										# The AS curve y-axis' intercept
	
end;

# ╔═╡ e3be2df9-6d5f-4541-ba35-ec65ebfeb4c3
begin
	Y5 = 12.0:0.01:15.0
	
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) # AD function
	πs5 = πs_min5 .+ γ5 .*Y5             # AS function
	
	trace9_0 = scatter(; x = [14,14] , y = [-7,14] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [14.0], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", 
					marker_size= "12", marker_color="Blue", 
					textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_3 = Layout(; height = 450,
					title_text ="Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.5, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 5])

   p9_3 = plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_3)
	
end

# ╔═╡ 43e8fd65-2d3a-41bc-a8d6-44cf412318ed
begin
	Y5_ΔĀ5 = 12.0:0.01:15.0
	
	πd_max5_ΔĀ5 = ((Ā5 .+ ΔĀ5) ./ (λ5 .* ϕ5)) .- r̄5 ./ λ5 # New max value of the AD function
	
	πd5_ΔĀ5 = πd_max5_ΔĀ5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5_ΔĀ5) # AD function
	
	
	trace9_4 = scatter(; x = Y5_ΔĀ5, y = πd5_ΔĀ5, mode="lines" , line_color = "Magenta", 
					 line_width = "3", name  = "AD2")
		
	trace9_5 = scatter(; x = [14.21], y = [2.947], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text", 
					marker_size= "12", marker_color="Magenta", 
					textfont = attr(family="sans serif", size=16, color="black"))

	
	πs5_self = πs_min5 .+ γ5 .* Y5_ΔĀ5 .+ self_correction            # AS function
	
	trace9_6 = scatter(; x = Y5_ΔĀ5, y = πs5_self, mode="lines" , line_color = "Coral", line_width = "3",
			name  = "AS2")	
	
	trace9_7 = scatter(; x = [14.0], y = [4.0], text =["3"], 
					textposition = "top center", name ="Eq3", mode="markers+text", 
					marker_size= "12", marker_color="Coral", 
					textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_5 = Layout(; height = 450,
					title_text = "A Positive Demand Shock to the Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.5, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 7])

   p9_6 = plot([trace9_0,trace9_1,trace9_2, trace9_4,trace9_6, trace9_3, trace9_5, trace9_7], layout9_5)
	
end

# ╔═╡ a1b1866b-3179-4829-a0cf-9bdbdb913c8c
begin
	Y6 = 12.0:0.02:15.0
	
	πs6 = πs_min5 .+ γ5 .*Y6 .+ ρ6            # AS function
	
	trace9_8 = scatter(; x = Y6, y = πs6, mode="lines" , line_color = "gray", line_width = "3",
			name  = "AS2")	
	
	trace9_9 = scatter(; x = [14.2], y = [1.0], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text",
					marker_size= "12", marker_color="red", 
					textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_9= Layout(; height = 450,
					title_text ="A Positive Temporary Supply Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.5, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-2 , 5])
	

    p9_9 = plot([trace9_0 , trace9_1, trace9_2, trace9_8 , trace9_3, trace9_9], layout9_9)
	
end

# ╔═╡ 2b1953d1-4bb8-42c6-98be-c353a44d8857
begin
	Y6_self6 = 12.0:0.01:15.0
	
	πs6_self6 = πs_min5 .+ γ5 .*Y6_self6 .+ ρ6  .+ self6           # AS function
	
	trace9_10 = scatter(; 
			x = Y6_self6, y = πs6_self6, mode="lines" , line_color = "green", line_width = "3",
			name  = "AS2")	
	
	trace9_11 = scatter(; x = [14.0], y = [2.0], text =["3"], 
					textposition = "bottom center", name ="Eq3", mode="markers+text", 
					marker_size= "12", marker_color="purple", 
					textfont = attr(family="sans serif", size=18, color="black"))
	

    p9_11 = plot([trace9_0,trace9_1,trace9_2, trace9_10, trace9_3, trace9_11, trace9_9], layout9_9)
	
end

# ╔═╡ f760841b-8a69-4aa4-a76b-edbf27f7de63
begin
	Y7 = 12.0:0.01:15.0
	
	trace9_12 = scatter(; x = [14.0.+ΔYᴾ ,14.0.+ΔYᴾ] , y = [-7,14] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	πs7 = πs_min5 .- γ5 .* ΔYᴾ .+ γ5 .* Y5 .+ ρ5  .+ self7           # AS function

	trace9_13 = scatter(; x = Y7, y = πs7, mode="lines" , line_color = "green", 
					line_width = "3", name  = "AS2")	
	
	layout9_13= Layout(; height = 450,
					title_text ="A Positive Permanent Supply Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.5, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1.0 , 5.0])
	

    p9_13 = plot([trace9_12, trace9_1,trace9_2, trace9_13, trace9_3, trace9_9], layout9_13)
	
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"

[compat]
HypertextLiteral = "~0.9.2"
NLsolve = "~4.5.1"
PlutoPlotly = "~0.6.2"
PlutoUI = "~0.7.16"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.11.3"
manifest_format = "2.0"
project_hash = "0f0dfb9f6efc2abd553105a1fd2af640a4798604"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "6e1d2a35f2f90a4bc7c2ed98079b2ba09c35b83a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.3.2"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "cd8b948862abee8f3d3e9b73a102a9ca924debb0"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "4.2.0"

    [deps.Adapt.extensions]
    AdaptSparseArraysExt = "SparseArrays"
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.2"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra"]
git-tree-sha1 = "017fcb757f8e921fb44ee063a7aafe5f89b86dd1"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.18.0"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceCUDSSExt = "CUDSS"
    ArrayInterfaceChainRulesCoreExt = "ChainRulesCore"
    ArrayInterfaceChainRulesExt = "ChainRules"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceReverseDiffExt = "ReverseDiff"
    ArrayInterfaceSparseArraysExt = "SparseArrays"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    CUDSS = "45b445bb-4962-46a0-9369-b4df9d0f772e"
    ChainRules = "082447d4-558c-5d27-93f4-14fc19e9eca2"
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    ReverseDiff = "37e2e3b7-166d-5795-8a7a-e32c996b4267"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"
version = "1.11.0"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"
version = "1.11.0"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "403f2d8e209681fcbd9468a8514efff3ea08452e"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.29.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "b10d0b65641d57b8b4d5e234446582de5047050d"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.5"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "362a287c3aa50601b0bc359053d5c2468f0e7ce0"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.11"

[[deps.CommonSubexpressions]]
deps = ["MacroTools"]
git-tree-sha1 = "cda2cfaebb4be89c9084adaca7dd7333369715c5"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.1"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.1.1+0"

[[deps.ConstructionBase]]
git-tree-sha1 = "76219f1ed5771adbb096743bff43fb5fdd4c1157"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.8"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseLinearAlgebraExt = "LinearAlgebra"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"
version = "1.11.0"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "c7e3a542b999843086e2f29dac96a618c105be1d"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.12"

    [deps.Distances.extensions]
    DistancesChainRulesCoreExt = "ChainRulesCore"
    DistancesSparseArraysExt = "SparseArrays"

    [deps.Distances.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"
version = "1.11.0"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"
version = "1.11.0"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Setfield"]
git-tree-sha1 = "f089ab1f834470c525562030c8cfde4025d5e915"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.27.0"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffSparseArraysExt = "SparseArrays"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "05882d6995ae5c12bb5f36dd2ed3f61c98cbb172"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.5"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "a2df1b776752e3f344e5116c06d75a10436ab853"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.38"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"
version = "1.11.0"

[[deps.HashArrayMappedTries]]
git-tree-sha1 = "2eaa69a7cab70a52b9687c8bf950a5a93ec895ae"
uuid = "076d061b-32b6-4027-95e0-9a2c6f6d7e74"
version = "0.2.0"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "179267cfa5e712760cd43dcae385d7ea90cc25a4"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.5"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "7134810b1afce04bbc1045ca1985fbe81ce17653"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.5"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "b6d6bfdd7ce25b0f9b2f6b3dd56b2673a66c8770"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.5"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"
version = "1.11.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "e2222959fbc6c19554dc15174c81bf7bf3aa691c"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.4"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "a007feb38b422fbdab534406aeca1b86823cb4d6"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.7.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.LaTeXStrings]]
git-tree-sha1 = "dda21b8cbd6a6c40d9d02a73230f9d70fed6918c"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.4.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.6.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
version = "1.11.0"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.7.2+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"
version = "1.11.0"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "e4c3be53733db1051cc15ecf573b1042b3a712a1"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.3.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
version = "1.11.0"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "13ca9e2586b89836fd20cccf56e57e2b9ae7f38f"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.29"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"
version = "1.11.0"

[[deps.MIMEs]]
git-tree-sha1 = "1833212fd6f580c20d4291da9c1b4e8a655b128e"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "1.0.0"

[[deps.MacroTools]]
git-tree-sha1 = "72aebe0b5051e5143a079a4685a46da330a40472"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.15"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"
version = "1.11.0"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.6+0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"
version = "1.11.0"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.12.12"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "cc0a5deefdb12ab3a096f00a6d42133af4560d71"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.1.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.27+1"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+2"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl"]
git-tree-sha1 = "1346c9208249809840c91b26703912dff463d335"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.6+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "cc4054e898b852042d7b503313f7ad03de99c3dd"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.8.0"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "8489905bcdbcfac64d1daa51ca07c0d8f0283821"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.8.1"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "Random", "SHA", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.11.0"
weakdeps = ["REPL"]

    [deps.Pkg.extensions]
    REPLExt = "REPL"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Colors", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "90af5c9238c1b3b25421f1fdfffd1e8fca7a7133"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.20"

    [deps.PlotlyBase.extensions]
    DataFramesExt = "DataFrames"
    DistributionsExt = "Distributions"
    IJuliaExt = "IJulia"
    JSON3Ext = "JSON3"

    [deps.PlotlyBase.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    Distributions = "31c24e10-a181-5473-b8eb-7969acd0382f"
    IJulia = "7073ff75-c697-5162-941a-fcdaad2a7d2a"
    JSON3 = "0f8b85d8-7281-11e9-16c2-39a750bddbf1"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "Artifacts", "ColorSchemes", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "PrecompileTools", "Reexport", "ScopedValues", "Scratch", "TOML"]
git-tree-sha1 = "9ebe25fc4703d4112cc418834d5e4c9a4b29087d"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.6.2"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "7e71a55b87222942f0f9337be62e26b1f103d3e4"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.61"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "5aa36f7049a63a1528fe8f7c3f2113413ffd4e1f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "9306f6085165d270f7e3db02af26a400d580f5c6"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.3"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"
version = "1.11.0"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "StyledStrings", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"
version = "1.11.0"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
version = "1.11.0"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.ScopedValues]]
deps = ["HashArrayMappedTries", "Logging"]
git-tree-sha1 = "1147f140b4c8ddab224c94efa9569fc23d63ab44"
uuid = "7e506255-f358-4e82-b7e4-beb19740aa63"
version = "1.3.0"

[[deps.Scratch]]
deps = ["Dates"]
git-tree-sha1 = "3bac05bc7e74a75fd9cba4295cde4045d9fe2386"
uuid = "6c6a2e73-6563-6170-7368-637461726353"
version = "1.2.1"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"
version = "1.11.0"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"
version = "1.11.0"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "64cca0c26b4f31ba18f13f6c12af7c85f478cfde"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.5.0"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "192954ef1208c7019899fbf8049e717f92959682"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.3"

[[deps.Statistics]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "ae3bb1eb3bba077cd276bc5cfc337cc65c3075c0"
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.11.1"

    [deps.Statistics.extensions]
    SparseArraysExt = ["SparseArrays"]

    [deps.Statistics.weakdeps]
    SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1ff449ad350c9c4cbc756624d6f8a8c3ef56d3ed"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.7.0"

[[deps.StyledStrings]]
uuid = "f489334b-da3d-4c2e-b8f0-e476e12c162b"
version = "1.11.0"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
version = "1.11.0"

[[deps.Tricks]]
git-tree-sha1 = "6cae795a5a9313bbb4f60683f7263318fc7d1505"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.10"

[[deps.URIs]]
git-tree-sha1 = "67db6cc7b3821e19ebe75791a9dd19c9b1188f2b"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.1"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"
version = "1.11.0"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"
version = "1.11.0"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.11.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.59.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─ee5192d8-a3fb-4a81-b9a0-746a19a2d7e0
# ╟─943edb36-acc8-4b2a-94ab-c544f9eb279b
# ╟─1245aef9-18ce-42f5-af82-c2e6cce70798
# ╟─a6c1f828-e06d-43f1-a26b-15cd3a26f7d4
# ╟─4618a663-f77e-4ccc-9b00-e84dbd5beb34
# ╠═a145e2fe-a903-11eb-160f-df7ea83fa3e6
# ╟─e593a1eb-4d26-4fdf-b1ac-c7da27d319ef
# ╟─0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
# ╟─5999a598-0408-44f1-bd33-c4d0fa5a6006
# ╟─f52137ff-9ac8-4bf1-930e-423b0347622a
# ╟─93ae1892-7c2d-4dec-925d-1803d77bd36a
# ╟─8034f9ea-d35d-4fa0-b246-503ee7c4fd60
# ╟─4b63f599-4622-472e-a7fb-685c522681dc
# ╟─1badc5a8-42dd-409a-a0aa-b33fcc3cfbf4
# ╟─c5c3b106-f7ec-44c4-abcd-03497f7873c7
# ╟─7342ebd8-e148-43a3-a9cb-24ea0ed917ac
# ╟─cf299465-4844-4580-83da-769c966e2569
# ╟─549d9eda-f104-4b6c-9524-5c08ea11e7b3
# ╟─906529c8-51e1-43c6-9ead-f162d9ffbb83
# ╟─0836abe7-5ea6-4189-b783-a2215b6acd72
# ╟─4ce820d4-9eb2-4acd-92c7-820cf46d08ae
# ╟─5726cb84-b09b-4efc-94da-19777ecabae4
# ╟─959f9b39-b525-4394-ae21-9453a45a28b1
# ╟─14972c0b-a403-4c98-b15e-ea033758c104
# ╟─5d0cee9b-73c6-4b7e-bb0f-6773be82f845
# ╟─c7da461d-1fc4-463e-bd46-900df67d1e03
# ╟─dc128d55-9ba7-44a1-aec8-f448f131746d
# ╟─c4e8ddf3-2501-42fc-a24d-84dd81026f33
# ╟─add07024-b7eb-445d-b4f4-6a6757c2ecd3
# ╟─498da362-6b02-4335-9525-ad82aa6fb5a2
# ╟─8e2203e6-6677-47b9-8032-e9c63c0f41bb
# ╠═a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
# ╟─a0d0e633-d674-4163-864f-db877bd9e986
# ╟─31625342-4ea6-4831-b131-dbd0195b6361
# ╟─7c8767ed-5600-49e5-869b-b1d3cd773f55
# ╠═af38d9e1-a2c2-4fd6-a06f-bf68813065e5
# ╟─732496c1-43d8-4457-bada-8a3255cbf43d
# ╟─e3be2df9-6d5f-4541-ba35-ec65ebfeb4c3
# ╟─d1f298ae-0249-420f-a0d4-f7548c5dd1c6
# ╟─ffb1afa6-5348-4dc3-9c63-3b01ecc63743
# ╟─8a3260f2-88a9-4c93-a936-e2688f4c0dea
# ╟─2c004ab0-8cc6-4d9f-8b50-35eadf58e92b
# ╟─ee80a41f-5d29-46b4-8f64-23b6f5a37895
# ╟─70d9bdc7-342f-40a0-bf1d-996b8acedd0c
# ╟─43e8fd65-2d3a-41bc-a8d6-44cf412318ed
# ╟─4a876a3f-e3b7-4fc3-a906-7fa91cb0728f
# ╟─7982723e-690b-494a-9560-8853ef8bc535
# ╟─dcd13560-0f73-4aaa-b59a-b7961d8cdc63
# ╟─7f67d656-bb55-4097-ba49-10140f9b3502
# ╟─82a2c755-960e-4eb7-a55a-e333eb85fa5f
# ╟─22fd1017-4015-407d-bd79-188a763e87a4
# ╠═a1b1866b-3179-4829-a0cf-9bdbdb913c8c
# ╟─18254af8-8305-4953-8ff8-3a1685605c06
# ╟─28052403-f02e-41dc-ba74-e42d88f3d494
# ╟─b95fd035-9752-428b-b908-206bf0bf26e6
# ╟─db702f28-e3e7-4d14-9209-1cbe2917247b
# ╟─2b1953d1-4bb8-42c6-98be-c353a44d8857
# ╟─5859e1fa-f4ef-42b7-a3fd-5085cd64161c
# ╟─6f7751bd-71c8-4cfd-982e-69690f401034
# ╟─ec34cbc5-fda5-4792-adc8-3bb0d02a7f22
# ╟─83c030a3-28bc-419f-968b-62ce9ab0a1e4
# ╟─996d86b1-736d-40fe-9426-c4bf64273259
# ╟─f760841b-8a69-4aa4-a76b-edbf27f7de63
# ╟─b731c7e2-1db6-4cee-bb97-c9267d89d099
# ╟─7e726480-d4c0-4389-abe8-d83f4dff3914
# ╟─6b3b698d-4cce-459d-af5a-bd756ffe0d19
# ╟─270c5421-dc6d-4278-861e-3d70a003858a
# ╟─39077452-b48d-475e-ae62-1a27f164128b
# ╟─bfd1415f-da2e-49ea-aee2-08eaa2537042
# ╟─6f7be7b0-6bab-4521-a344-86a559f2a107
# ╟─e1db11e3-f0fb-41e1-b9ad-52a2792c2fe3
# ╟─57864011-a2c9-410a-b6c9-9d27ee2cb74a
# ╟─e1bf534b-55a6-490c-8038-ddedc6ec6475
# ╟─60c7a5e9-9d69-4cd8-8d8a-e02b7910ff05
# ╟─8ed2e8bd-546f-41d0-acb8-ffee83c29b6e
# ╟─487a5208-4cc6-489e-8613-3fa8d5bc0603
# ╟─1b4b25ee-89cb-4322-b358-994fe912cc74
# ╟─e10c1813-957e-4da8-90dc-8ced5d2084d1
# ╟─af27ace7-dc5b-444b-b4c7-7848f5922584
# ╟─235353dd-e5f0-4830-b1bc-ae3de9787168
# ╠═84e2f9cd-f9b0-40ac-b65c-6be18bcb80d7
# ╟─07f14b05-4049-4a4f-a3a7-0b2e1c48b8a1
# ╟─26fe310e-9ed8-4d09-bb82-a5bd39193dde
# ╟─23a5d2a0-d780-4e7b-be00-1f8851fd5d86
# ╟─b7d79351-21e6-491b-89f0-7ab76b437eef
# ╟─b974cf81-fa40-47fb-a362-ac7ec6e20a94
# ╟─b108dd56-8868-460d-a042-d38a4bcb10d6
# ╟─7e0ae435-0c4d-45b3-b021-9c17cde55edc
# ╟─be4b71e0-d6ee-4e14-bb0b-5c1eefb03757
# ╟─7f7f259b-fb40-4c45-a78c-24d9be188c55
# ╟─e16fd560-114f-4e13-938b-1604ff43c273
# ╟─0bba272d-1d00-4ea8-9583-dff318cd8b36
# ╟─cbdd006a-2fc3-48c0-9a4b-d7705e88bd41
# ╟─dd6bcb46-31de-40d1-af36-2db046dde140
# ╟─324f74c7-fe71-4bd6-baf0-51f8c3211006
# ╟─68e70c98-2a58-474d-89dd-76f2db735e5a
# ╟─00b94ba0-4536-499e-8e4e-8d78f50be9f9
# ╟─83888153-57b4-4cc2-adde-3eb65d2dc70d
# ╟─9fa87191-7c90-4738-a45a-acd929c8bd1b
# ╟─b3ead675-fabb-418c-92b7-3d37bce22614
# ╟─07fb6f85-d9c2-4f3b-9988-eb5ba294fb34
# ╟─19930b0f-e3f0-45e0-b829-9def3f828bbc
# ╟─3d970676-1703-4773-8fd5-8a415fea2b69
# ╟─505df01a-8e06-43c0-8c36-3548f2fa1e97
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
